SentryMonitoringService class

Sentry implementation of MonitoringService.

This service expects Sentry to be pre-initialized by the LittlefishObservabilityManager before initailize is called. It uses the existing Sentry instance via Sentry.clone().

Inheritance

Constructors

SentryMonitoringService()

Properties

core ↔ LittleFishCore
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isReady bool
no setterinherited
isSetup bool?
no setterinherited
kInstance ↔ Hub?
getter/setter pairinherited
logger → LoggerService
no setterinherited
providerName String?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings ↔ MonitoringSettings?
getter/setter pairinherited

Methods

createHttpTrace({required String name, required String url, required MonitoringHttpMethod method}) Future<SentryHttpMetric>
override
createTrace({required String name, String operation = 'custom'}) Future<SentryTrace>
override
initailize({required MonitoringSettings settings}) Future<void>
override
monitorAction<R>({required String actionName, required String provider, required Future<R> action(SentryTrace trace), Map<String, dynamic>? attributes, Map<String, dynamic> resultParser(R result)?, bool logAnalytics = true, String? analyticsEventName}) Future<R>
Method for executing actions with: Performance Tracing (Start/Stop), Automatic Metadata Injection, Direct Analytics Logging
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIsReady({required bool isReady}) Future<void>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited