SentryTrace class

Inheritance
  • Object
  • MonitoringTrace<ISentrySpan>
  • SentryTrace

Constructors

SentryTrace({required String name, String operation = 'custom'})

Properties

hashCode int
The hash code for this object.
no setterinherited
kCanTrace bool
getter/setter pairinherited
kInstance ↔ ISentrySpan?
getter/setter pairinherited
logger ↔ LoggerService?
getter/setter pair
name String
getter/setter pairinherited
operation String
The semantic operation type for this trace (e.g. 'auth', 'app.start', 'db'). Follows OpenTelemetry conventions used by Sentry.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAttribute(String key) Future<String?>
override
getAttributes() Future<Map<String, String>>
override
getMetric(String key) Future<int>
override
initialize({bool autoStart = true, bool canTrace = false}) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putAttribute(String key, String value) Future<void>
override
setMetric(String key, int value) Future<void>
override
start() Future<void>
override
stop() Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited